abacusai.bot_info — AbacusAI documentation

# abacusai.bot_info

## Classes

`BotInfo` | Information about an external application and LLM.

## Module Contents

class abacusai.bot_info.BotInfo(client, externalApplicationId=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Information about an external application and LLM.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - externalApplicationId (str) – The external application ID.

  external_application_id = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict